psychopy_ext.fmri.Analysis.correlation — psychopy_ext 0.5.4 documentation
Author: Jonas Kubilius
Description: A framework for a rapid reproducible design, analysis and plotting of experiments in neuroscience and psychology

# psychopy_ext.fmri.Analysis.correlation

`Analysis.` `correlation`(evds, nIter=100)

  Computes pairwise correlations between the two data splits in half.

  Reported as one minus a correlation over two to provide a dissimilarity measure between 0 and 1 as in `svm()`.

  Data is normalized by subtracting the mean across conditions (targets) per chunk per voxel.

  Args: | evds (event-related mvpa dataset)
  Kwargs: | nIter (int, default: 100) Number of random splits in half of the entire dataset.
  Returns: | A header and a results matrix with four columns: iter: iteration number stim1.cond: first condition stim2.cond: second condition subj_resp: one minus the correlation value over two (0: patterns identical, 1: patterns have nothing in common)